
# How to cite GeoCAT-datafiles

If you use this software, please cite it as described below:

Each GeoCAT-datafiles version is assigned a separate Digital Object Identifier (DOI) to allow
users to access older releases. This ensures that users are not only able to cite the specific
software version through DOIs but are also able to download & use the corresponding release for
reproducibility purposes.

If you would like to cite GeoCAT-datafiles as a whole (without referring to a specific version), use
the following text:

**Visualization & Analysis Systems Technologies. (2020).
Geoscience Community Analysis Toolkit: GeoCAT-datafiles [Software].
Boulder, CO: NSF NCAR Computational and Information Systems Lab. doi:10.5281/zenodo.6684782.**

Instead, if you would like to cite a specific version of GeoCAT-datafiles, use the following text:

**Visualization & Analysis Systems Technologies. (\<Year\>).
Geoscience Community Analysis Toolkit: GeoCAT-datafiles (v\<version\>) [Software].
Boulder, CO, USA: NSF NCAR Computational and Information Systems Lab. doi:\<DOI\>.**

In the above citation text, update the year, GeoCAT-datafiles version, and DOI as appropriate. For
example:

**Visualization & Analysis Systems Technologies. (2022).
Geoscience Community Analysis Toolkit: GeoCAT-datafiles (v2022.03.0) [Software].
Boulder, CO, USA: NSF NCAR Computational and Information Systems Lab. doi:10.5281/zenodo.6684830.**

Please find DOIs for all the GeoCAT-datafiles versions [here](
https://zenodo.org/search?page=1&size=20&q=conceptrecid:%226684782%22&sort=-version&all_versions=True).

Please note: The DOI minting service, Zenodo, might be suggesting their own citation text (as
they are the publisher of such DOIs) in their website. We prefer the text we recommend here to be used;
however, either way is acceptable.

For further information, please refer to
[GeoCAT homepage - Citation](https://geocat.ucar.edu/pages/citation.html).
